Enum git_conventional::ErrorKind[][src]

#[non_exhaustive]pub enum ErrorKind {
    MissingType,
    InvalidScope,
    MissingDescription,
    InvalidBody,
    InvalidFooter,
    InvalidFormat,
}

All possible error kinds returned when parsing a conventional commit.

Variants (Non-exhaustive)

Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingType

The commit type is missing from the commit message.

InvalidScope

The scope has an invalid format.

MissingDescription

The description of the commit is missing.

InvalidBody

The body of the commit has an invalid format.

InvalidFooter

The footer of the commit has an invalid format.

InvalidFormat

Any other part of the commit does not conform to the conventional commit spec.